==> hasktags-0.73.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-9q5YbuORF4Y39g2PXvA9QA
key:                  hasktags-0.73.0-9q5YbuORF4Y39g2PXvA9QA
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  ae08fed96275f2b92b2a0ac3dd6583bc
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-9q5YbuORF4Y39g2PXvA9QA
depends:
    base-4.16.4.0 bytestring-0.11.4.0 directory-1.3.6.2
    filepath-1.4.2.2 json-0.10-LFyMaiO4bwCHFN9cCB4OtD
    microlens-platform-0.4.3.5-wwYwgsx5ajCmOV9RDcs2r
    utf8-string-1.0.2-CndrelvclEbJyymwdX0DqC

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.73.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-25Cky8tJFVT2TeQK6zx3X4
key:                  hasktags-0.73.0-25Cky8tJFVT2TeQK6zx3X4
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  8c3916205bb4528643a681afcf185de7
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-25Cky8tJFVT2TeQK6zx3X4
depends:
    base-4.16.4.0 bytestring-0.11.4.0 directory-1.3.6.2
    filepath-1.4.2.2 json-0.10-LFyMaiO4bwCHFN9cCB4OtD
    microlens-platform-0.4.3.5-3aev5c0YNIl3BSqxlCS7Ck
    utf8-string-1.0.2-CndrelvclEbJyymwdX0DqC

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
